@@ -382,7 +382,7 @@ class LiveRegionManager:
     def matchLiveRegion(self, obj):
         """Predicate used to find a live region"""
         attrs = self._getAttrDictionary(obj)
-        return attrs.has_key('container-live')
+        return 'container-live' in attrs
 
     def _getMessage(self, event):
         """Gets the message associated with a given live event."""
@@ -447,7 +447,16 @@ class LiveRegionManager:
         # Get the labeling information now that we have good content.
         labels = self._getLabelsAsUtterances(event.source)
 
-        return {'content':content, 'labels':labels}
+        # instantly send out notify messages
+        if 'channel' in attrs and attrs['channel'] == 'notify':
+            utts = labels + content
+            speech.stop()
+            # Note: we would like to use a different ACSS for alerts.  This work
+            # should be done as part of bug #412656.
+            speech.speakUtterances(utts)
+            return None
+        else:
+            return {'content':content, 'labels':labels}
 
     def flushMessages(self):
         self.msg_queue.clear()
@@ -476,7 +485,8 @@ class LiveRegionManager:
                 # Note: getRowHeader() fails for most markup.  We will use the
                 # relation when the markup is good (when getRowHeader() works) 
                 # so we won't see this code in those cases.  
-                row = itable.getRowAtIndex(obj.getIndexInParent())
+                index = self._script.getCellIndex(obj)
+                row = itable.getRowAtIndex(index)
                 header = itable.getAccessibleAt(row, 0)
                 # expand the header
                 return [self._script.expandEOCs(header).strip()]
@@ -486,7 +496,7 @@ class LiveRegionManager:
             # Last ditch effort is to see if our parent is a table row <tr> 
             # element.
             parentattrs = self._getAttrDictionary(obj.parent) 
-            if parentattrs.has_key('tag') and parentattrs['tag'] == 'TR':
+            if 'tag' in parentattrs and parentattrs['tag'] == 'TR':
                 return [self._script.expandEOCs( \
                                   obj.parent.getChildAtIndex(0)).strip()]
 
@@ -498,7 +508,7 @@ class LiveRegionManager:
         registers LIVE_NONE objects in politeness overrides when monitoring."""
         objectid = self._getObjectId(obj)
         uri = self._script.bookmarks.getURIKey()
-        if self._politenessOverrides.has_key((uri, objectid)):
+        if (uri, objectid) in self._politenessOverrides:
             # look to see if there is a user politeness override
             return self._politenessOverrides[(uri, objectid)]
         else:
@@ -552,7 +562,10 @@ class LiveRegionManager:
         else: return 'unknown'
 
     def _getAttrDictionary(self, obj):
-        return dict([attr.split(':', 1) for attr in obj.getAttributes()])
+        try:
+            return dict([attr.split(':', 1) for attr in obj.getAttributes()])
+        except:
+            return {}
     
     def _getPath(self, obj):
         """ Returns, as a tuple of integers, the path from the given object 
