@@ -21,17 +21,14 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 4190 2008-09-11 15:28:56Z wwalker $"
-__version__   = "$Revision: 4190 $"
-__date__      = "$Date: 2008-09-11 11:28:56 -0400 (Thu, 11 Sep 2008) $"
+__id__        = "$Id: settings.py 4365 2008-11-24 15:30:25Z wwalker $"
+__version__   = "$Revision: 4365 $"
+__date__      = "$Date: 2008-11-24 10:30:25 -0500 (Mon, 24 Nov 2008) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import os
 import re
-import shutil
-
-import platform
 
 screenWidth = 640
 screenHeight = 480
@@ -109,6 +106,7 @@ userCustomizableSettings = [
     "enableNavigationKeys",
     "enableTutorialMessages",
     "enableBraille",
+    "enableBrailleContext",
     "enableBrailleGrouping",
     "disableBrailleEOL",
     "brailleEOLIndicator",
@@ -343,6 +341,12 @@ enableSpeechIndentation = False
 #
 enableBraille           = True
 
+# If True, add the hierarchical context of an object to the braille
+# line.  People with very large braille displays may want to set this
+# to False.
+#
+enableBrailleContext    = True
+
 # If True, enable the grouping of children on the braille display.
 # This is for things like displaying all items of a menu, tab list,
 # menu bar, etc., on a single line of the braille display.
@@ -840,10 +844,12 @@ def setAccessibilityEnabled(enable):
 def isOrcaAutostarted():
     """Return an indication of whether Orca autostart at login time is enabled.
     """
-
-    userDesktopFile = os.path.join(os.environ["HOME"], ".config", \
-                                   "autostart", "orca.desktop")
-    return os.path.exists(userDesktopFile)
+    prefix = "/desktop/gnome/applications/at/visual/"
+    try:
+        return ("orca" in gconfClient.get_string(prefix + "exec")) \
+           and gconfClient.get_bool(prefix + "startup")
+    except:
+        return False
 
 def setOrcaAutostart(enable):
     """Enable or disable the autostart of Orca at login time.
@@ -853,34 +859,12 @@ def setOrcaAutostart(enable):
 
     Returns an indication of whether the operation was successful.
     """
-
-    status = True
-    systemDesktopFile = os.path.join(platform.prefix, platform.datadirname, \
-                                     "applications", "orca.desktop")
-    autostartDir = os.path.join(os.environ["HOME"], ".config", "autostart")
-    userDesktopFile = os.path.join(os.environ["HOME"], ".config", \
-                                   "autostart", "orca.desktop")
-
+    prefix = "/desktop/gnome/applications/at/visual/"
     try:
-        # If the user wants to enable Orca autostart, then copy the
-        # orca.desktop file from /usr/share/applications to
-        # ~/.config/autostart directory (creating the autostart directory
-        # if neccessary).
-        #
-        # If the user wants to disable this feature, then just remove 
-        # ~/.config/autostart/orca.desktop (if it exists).
-        #
-        if enable:
-            try:
-                os.chdir(autostartDir)
-            except:
-                os.mkdir(autostartDir)
-            shutil.copy(systemDesktopFile, userDesktopFile)
-        else:
-            os.remove(userDesktopFile)
+        return gconfClient.set_string(prefix + "exec", "orca") \
+           and gconfClient.set_bool(prefix + "startup", enable)
     except:
-        status = False
-    return status
+        return False
 
 # Obtain/set information regarding whether the gksu keyboard grab is enabled
 # or not.
@@ -1016,6 +1000,11 @@ setScriptMapping(re.compile(_('Bon Echo')), "Mozilla")
 #
 setScriptMapping(re.compile(_('Minefield')), "Mozilla")
 
+# This is a temporary fix for the schema/FF 3.0 not being accessible
+# issue. (See GNOME bugs #535827 and #555466.)
+#
+setScriptMapping(re.compile('[Ff]irefox'), "Mozilla")
+
 # Translators: see the regular expression note above.  This is for a
 # version of Thunderbird, which chooses to now call itself by a different
 # name.
