@@ -23,9 +23,9 @@ class.  For those wishing to override the speech generators, however,
 one can create a new instance and replace/extend the speech generators
 as they see fit."""
 
-__id__        = "$Id: speechgenerator.py 4098 2008-08-12 17:56:14Z joanied $"
-__version__   = "$Revision: 4098 $"
-__date__      = "$Date: 2008-08-12 13:56:14 -0400 (Tue, 12 Aug 2008) $"
+__id__        = "$Id: speechgenerator.py 4161 2008-09-06 18:30:21Z joanied $"
+__version__   = "$Revision: 4161 $"
+__date__      = "$Date: 2008-09-06 14:30:21 -0400 (Sat, 06 Sep 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1867,12 +1867,11 @@ class SpeechGenerator:
                     #
                     if parent.getRole() not in [pyatspi.ROLE_TABLE_CELL,
                                                 pyatspi.ROLE_FILLER]:
-                        utterances.append(\
-                            rolenames.getSpeechForRoleName(parent))
+                        utterances.extend(self.getSpeechForObjectRole(parent))
                     utterances.append(text)
                     if parent.getRole() == pyatspi.ROLE_TABLE_CELL:
-                        utterances.append(\
-                            rolenames.getSpeechForRoleName(parent))
+                        utterances.extend(self.getSpeechForObjectRole(parent))
+
             parent = parent.parent
 
         utterances.reverse()
